@@ -102,6 +102,7 @@ VM_GEN_2 = 2
 JOB_STATE_COMPLETED = 7
 JOB_STATE_TERMINATED = 8
 JOB_STATE_KILLED = 9
+JOB_STATE_EXCEPTION = 10
 JOB_STATE_COMPLETED_WITH_WARNINGS = 32768
 
 # Special vlan_id value in ovs_vlan_allocations table indicating flat network
@@ -141,3 +142,59 @@ IPV4_DEFAULT = '0.0.0.0'
 FSK_COMPUTERNAME = 'ComputerName'
 
 VTPM_SUPPORTED_OS = ['windows']
+
+# DNSUtils constants
+DNS_ZONE_TYPE_PRIMARY = 0
+DNS_ZONE_TYPE_SECONDARY = 1
+DNS_ZONE_TYPE_STUB = 2
+DNS_ZONE_TYPE_FORWARD = 3
+
+DNS_ZONE_NO_UPDATES_ALLOWED = 0
+DNS_ZONE_SECURE_NONSECURE_UPDATES = 1
+DNS_ZONE_SECURE_UPDATES_ONLY = 2
+
+DNS_ZONE_DO_NOT_NOTIFY = 0
+DNS_ZONE_NOTIFY_NAME_SERVERS_TAB = 1
+DNS_ZONE_NOTIFY_SPECIFIED_SERVERS = 2
+
+DNS_ZONE_TRANSFER_ALLOWED_ANY_HOST = 0
+DNS_ZONE_TRANSFER_ALLOWED_NAME_SERVERS = 1
+DNS_ZONE_TRANSFER_ALLOWED_SECONDARY_SERVERS = 2
+DNS_ZONE_TRANSFER_NOT_ALLOWED = 3
+
+CLUSTER_GROUP_STATE_UNKNOWN = -1
+CLUSTER_GROUP_ONLINE = 0
+CLUSTER_GROUP_OFFLINE = 1
+CLUSTER_GROUP_FAILED = 2
+CLUSTER_GROUP_PARTIAL_ONLINE = 3
+CLUSTER_GROUP_PENDING = 4
+
+EXPORT_CONFIG_SNAPSHOTS_ALL = 0
+EXPORT_CONFIG_NO_SNAPSHOTS = 1
+EXPORT_CONFIG_ONE_SNAPSHOT = 2
+
+# ACE inheritance flags
+ACE_OBJECT_INHERIT = 0x1
+ACE_CONTAINER_INHERIT = 0x2
+ACE_NO_PROPAGATE_INHERIT = 0x4
+ACE_INHERIT_ONLY = 0x8
+ACE_INHERITED = 0x10
+
+# ACE access masks
+ACE_GENERIC_READ = 0x80000000
+ACE_GENERIC_WRITE = 0x40000000
+ACE_GENERIC_EXECUTE = 0x20000000
+ACE_GENERIC_ALL = 0x10000000
+
+# ACE access modes
+ACE_NOT_USED_ACCESS = 0
+ACE_GRANT_ACCESS = 1
+ACE_SET_ACCESS = 2
+ACE_DENY_ACCESS = 3
+ACE_REVOKE_ACCESS = 4
+ACE_SET_AUDIT_SUCCESS = 5
+ACE_SET_AUDIT_FAILURE = 6
+
+# VLAN operation modes
+VLAN_MODE_ACCESS = 1
+VLAN_MODE_TRUNK = 2
