@@ -24,21 +24,13 @@ from os_win._i18n import _
 # Define WMI specific exceptions, so WMI won't have to be imported in any
 # module that expects those exceptions.
 if sys.platform == 'win32':
-    from six.moves.builtins import WindowsError
     import wmi
 
     x_wmi = wmi.x_wmi
     x_wmi_timed_out = wmi.x_wmi_timed_out
 else:
-    class WindowsError(Exception):
-        def __init__(self, winerror=None):
-            self.winerror = winerror
-
     class x_wmi(Exception):
-        def __init__(self, info='', com_error=None):
-            super(x_wmi, self).__init__()
-            self.info = info
-            self.com_error = com_error
+        pass
 
     class x_wmi_timed_out(x_wmi):
         pass
@@ -49,7 +41,6 @@ class OSWinException(Exception):
 
     def __init__(self, message=None, **kwargs):
         self.kwargs = kwargs
-        self.error_code = kwargs.get('error_code')
 
         if not message:
             message = self.msg_fmt % kwargs
@@ -86,10 +77,6 @@ class HyperVPortNotFoundException(NotFound, HyperVException):
     msg_fmt = _("Switch port not found: %(port_name)s")
 
 
-class HyperVvNicNotFound(NotFound, HyperVException):
-    msg_fmt = _("vNic not found: %(vnic_name)s")
-
-
 class SMBException(OSWinException):
     pass
 
@@ -99,6 +86,10 @@ class Win32Exception(OSWinException):
                 "Error code: %(error_code)s. "
                 "Error message: %(error_message)s")
 
+    def __init__(self, message=None, **kwargs):
+        self.error_code = kwargs.get('error_code')
+        super(Win32Exception, self).__init__(message=message, **kwargs)
+
 
 class VHDException(OSWinException):
     pass
