@@ -112,6 +112,7 @@ class VMUtils(baseutils.BaseUtilsVirt):
 
     _vm_power_states_map = {constants.HYPERV_VM_STATE_ENABLED: 2,
                             constants.HYPERV_VM_STATE_DISABLED: 3,
+                            constants.HYPERV_VM_STATE_SHUTTING_DOWN: 4,
                             constants.HYPERV_VM_STATE_REBOOT: 11,
                             constants.HYPERV_VM_STATE_PAUSED: 9,
                             constants.HYPERV_VM_STATE_SUSPENDED: 6}
@@ -269,6 +270,15 @@ class VMUtils(baseutils.BaseUtilsVirt):
 
         self._jobutils.modify_virt_resource(procsetting)
 
+    def set_nested_virtualization(self, vm_name, state):
+        """Enables nested virtualization for the given VM.
+
+        :raises NotImplemented: Nested virtualization is supported on
+            Windows / Hyper-V Server 2016 or newer.
+        """
+        raise NotImplementedError(_('Nested virtualization is supported on '
+                                    'Windows / Hyper-V Server 2016 or newer.'))
+
     def update_vm(self, vm_name, memory_mb, memory_per_numa_node, vcpus_num,
                   vcpus_per_numa_node, limit_cpu_features, dynamic_mem_ratio,
                   configuration_root_dir=None, snapshot_dir=None,
@@ -276,7 +286,7 @@ class VMUtils(baseutils.BaseUtilsVirt):
         virtual_system_type = self._get_virtual_system_type(is_planned_vm)
 
         vmsetting = self._lookup_vm_check(
-            vm_name, for_update=True, virtual_system_type=virtual_system_type)
+            vm_name, virtual_system_type=virtual_system_type)
 
         if configuration_root_dir:
             vmsetting.ConfigurationDataRoot = configuration_root_dir
