@@ -21,15 +21,11 @@ Hyper-V Server / Windows Server 2012.
 import functools
 import re
 
-from eventlet import greenthread
 from eventlet import patcher
 from eventlet import tpool
-import sys
-
-if sys.platform == 'win32':
-    import wmi
 
 from os_win._i18n import _
+from os_win import constants
 from os_win import exceptions
 from os_win.utils import _wqlutils
 from os_win.utils import baseutils
@@ -51,7 +47,6 @@ class NetworkUtils(baseutils.BaseUtilsVirt):
     _PORT_EXT_ACL_SET_DATA = _PORT_ALLOC_ACL_SET_DATA
     _LAN_ENDPOINT = 'Msvm_LANEndpoint'
     _STATE_DISABLED = 3
-    _OPERATION_MODE_ACCESS = 1
 
     _VIRTUAL_SYSTEM_SETTING_DATA = 'Msvm_VirtualSystemSettingData'
     _VM_SUMMARY_ENABLED_STATE = 100
@@ -231,7 +226,7 @@ class NetworkUtils(baseutils.BaseUtilsVirt):
                 try:
                     event = listen()
                     callback(event.ElementName)
-                except wmi.x_wmi_timed_out:
+                except exceptions.x_wmi_timed_out:
                     # no new event published.
                     pass
 
@@ -296,7 +291,7 @@ class NetworkUtils(baseutils.BaseUtilsVirt):
         if not vnic_deleted:
             try:
                 self._jobutils.remove_virt_resource(sw_port)
-            except wmi.x_wmi:
+            except exceptions.x_wmi:
                 # port may have already been destroyed by Hyper-V
                 pass
 
@@ -304,28 +299,60 @@ class NetworkUtils(baseutils.BaseUtilsVirt):
         self._vlan_sds.pop(sw_port.InstanceID, None)
         self._vsid_sds.pop(sw_port.InstanceID, None)
 
-    def set_vswitch_port_vlan_id(self, vlan_id, switch_port_name):
+    def set_vswitch_port_vlan_id(self, vlan_id=None, switch_port_name=None,
+                                 **kwargs):
+        """Sets up operation mode, VLAN ID and VLAN trunk for the given port.
+
+        :param vlan_id: the VLAN ID to be set for the given switch port.
+        :param switch_port_name: the ElementName of the vSwitch port.
+        :param operation_mode: the VLAN operation mode. The acceptable values
+            are:
+            os_win.constants.VLAN_MODE_ACCESS, os_win.constants.VLAN_TRUNK_MODE
+            If not given, VLAN_MODE_ACCESS is used by default.
+        :param trunk_vlans: an array of VLAN IDs to be set in trunk mode.
+        :raises AttributeError: if an unsupported operation_mode is given, or
+            the given operation mode is VLAN_MODE_ACCESS and the given
+            trunk_vlans is not None.
+        """
+
+        operation_mode = kwargs.get('operation_mode',
+                                    constants.VLAN_MODE_ACCESS)
+        trunk_vlans = kwargs.get('trunk_vlans')
+
+        if operation_mode not in [constants.VLAN_MODE_ACCESS,
+                                  constants.VLAN_MODE_TRUNK]:
+            msg = _('Unsupported VLAN operation mode: %s')
+            raise AttributeError(msg % operation_mode)
+
+        if (operation_mode == constants.VLAN_MODE_ACCESS and
+                trunk_vlans is not None):
+            raise AttributeError(_('The given operation mode is ACCESS, '
+                                   'cannot set given trunk_vlans.'))
+
         port_alloc = self._get_switch_port_allocation(switch_port_name)[0]
-
         vlan_settings = self._get_vlan_setting_data_from_port_alloc(port_alloc)
-        if vlan_settings:
-            if (vlan_settings.OperationMode == self._OPERATION_MODE_ACCESS and
-                    vlan_settings.AccessVlanId == vlan_id):
-                # VLAN already set to corect value, no need to change it.
-                return
 
+        if operation_mode == constants.VLAN_MODE_ACCESS:
+            new_vlan_settings = self._prepare_vlan_sd_access_mode(
+                vlan_settings, vlan_id)
+        else:
+            new_vlan_settings = self._prepare_vlan_sd_trunk_mode(
+                vlan_settings, vlan_id, trunk_vlans)
+
+        if not new_vlan_settings:
+            # if no object was returned, it means that the VLAN Setting Data
+            # was already added with the desired attributes.
+            return
+
+        if vlan_settings:
             # Removing the feature because it cannot be modified
             # due to a wmi exception.
             self._jobutils.remove_virt_feature(vlan_settings)
 
-            # remove from cache.
-            self._vlan_sds.pop(port_alloc.InstanceID, None)
+        # remove from cache.
+        self._vlan_sds.pop(port_alloc.InstanceID, None)
 
-        vlan_settings = self._create_default_setting_data(
-            self._PORT_VLAN_SET_DATA)
-        vlan_settings.AccessVlanId = vlan_id
-        vlan_settings.OperationMode = self._OPERATION_MODE_ACCESS
-        self._jobutils.add_virt_feature(vlan_settings, port_alloc)
+        self._jobutils.add_virt_feature(new_vlan_settings, port_alloc)
 
         # TODO(claudiub): This will help solve the missing VLAN issue, but it
         # comes with a performance cost. The root cause of the problem must
@@ -335,36 +362,86 @@ class NetworkUtils(baseutils.BaseUtilsVirt):
             raise exceptions.HyperVException(
                 _('Port VLAN not found: %s') % switch_port_name)
 
-    def set_vswitch_port_vsid(self, vsid, switch_port_name):
-        port_alloc = self._get_switch_port_allocation(switch_port_name)[0]
+    def _prepare_vlan_sd_access_mode(self, vlan_settings, vlan_id):
+        if vlan_settings:
+            # the given vlan_id might be None.
+            vlan_id = vlan_id or vlan_settings.AccessVlanId
+            if (vlan_settings.OperationMode == constants.VLAN_MODE_ACCESS and
+                    vlan_settings.AccessVlanId == vlan_id):
+                # VLAN already set to correct value, no need to change it.
+                return None
 
-        vsid_settings = self._get_security_setting_data_from_port_alloc(
+        vlan_settings = self._create_default_setting_data(
+            self._PORT_VLAN_SET_DATA)
+        vlan_settings.AccessVlanId = vlan_id
+        vlan_settings.OperationMode = constants.VLAN_MODE_ACCESS
+
+        return vlan_settings
+
+    def _prepare_vlan_sd_trunk_mode(self, vlan_settings, vlan_id, trunk_vlans):
+        if vlan_settings:
+            # the given vlan_id might be None.
+            vlan_id = vlan_id or vlan_settings.NativeVlanId
+            trunk_vlans = trunk_vlans or vlan_settings.TrunkVlanIdArray or []
+            trunk_vlans = sorted(trunk_vlans)
+            if (vlan_settings.OperationMode == constants.VLAN_MODE_TRUNK and
+                    vlan_settings.NativeVlanId == vlan_id and
+                    sorted(vlan_settings.TrunkVlanIdArray) == trunk_vlans):
+                # VLAN already set to correct value, no need to change it.
+                return None
+
+        vlan_settings = self._create_default_setting_data(
+            self._PORT_VLAN_SET_DATA)
+        vlan_settings.NativeVlanId = vlan_id
+        vlan_settings.TrunkVlanIdArray = trunk_vlans
+        vlan_settings.OperationMode = constants.VLAN_MODE_TRUNK
+
+        return vlan_settings
+
+    def set_vswitch_port_vsid(self, vsid, switch_port_name):
+        self._set_switch_port_security_settings(switch_port_name,
+                                                VirtualSubnetId=vsid)
+
+    def set_vswitch_port_mac_spoofing(self, switch_port_name, state):
+        """Sets the given port's MAC spoofing to the given state.
+
+        :param switch_port_name: the name of the port which will have MAC
+            spoofing set to the given state.
+        :param state: boolean, if MAC spoofing should be turned on or off.
+        """
+        self._set_switch_port_security_settings(switch_port_name,
+                                                AllowMacSpoofing=state)
+
+    def _set_switch_port_security_settings(self, switch_port_name, **kwargs):
+        port_alloc = self._get_switch_port_allocation(switch_port_name)[0]
+        sec_settings = self._get_security_setting_data_from_port_alloc(
             port_alloc)
 
-        if vsid_settings:
-            if vsid_settings.VirtualSubnetId == vsid:
-                # VSID already added, no need to readd it.
+        if sec_settings:
+            if all(getattr(sec_settings, k) == v for k, v in kwargs.items()):
+                # All desired properties already properly set. Nothing to do.
                 return
+
             # Removing the feature because it cannot be modified
             # due to a wmi exception.
-            self._jobutils.remove_virt_feature(vsid_settings)
+            self._jobutils.remove_virt_feature(sec_settings)
+        else:
+            sec_settings = self._create_default_setting_data(
+                self._PORT_SECURITY_SET_DATA)
 
-            # remove from cache.
-            self._vsid_sds.pop(port_alloc.InstanceID, None)
+        for k, v in kwargs.items():
+            setattr(sec_settings, k, v)
 
-        vsid_settings = self._create_default_setting_data(
-            self._PORT_SECURITY_SET_DATA)
-        vsid_settings.VirtualSubnetId = vsid
-        self._jobutils.add_virt_feature(vsid_settings, port_alloc)
+        self._jobutils.add_virt_feature(sec_settings, port_alloc)
 
         # TODO(claudiub): This will help solve the missing VSID issue, but it
         # comes with a performance cost. The root cause of the problem must
         # be solved.
-        vsid_settings = self._get_security_setting_data_from_port_alloc(
+        sec_settings = self._get_security_setting_data_from_port_alloc(
             port_alloc)
-        if not vsid_settings:
+        if not sec_settings:
             raise exceptions.HyperVException(
-                _('Port VSID not found: %s') % switch_port_name)
+                _('Port Security Settings not found: %s') % switch_port_name)
 
     def _get_vlan_setting_data_from_port_alloc(self, port_alloc):
         return self._get_setting_data_from_port_alloc(
@@ -538,9 +615,6 @@ class NetworkUtils(baseutils.BaseUtilsVirt):
             # is not processed twice.
             processed_sg_rules.append(sg_rule)
 
-            # yielding to other threads that must run (like state reporting)
-            greenthread.sleep()
-
         if add_acls:
             self._jobutils.add_multiple_virt_features(add_acls, port)
 
